======
cfglib
======


.. image:: https://img.shields.io/pypi/v/cfglib.svg
        :target: https://pypi.python.org/pypi/cfglib

.. image:: https://github.com/swarmer/cfglib-py/workflows/CI/badge.svg
        :target: https://github.com/swarmer/cfglib-py/actions
        :alt: CI Status

.. image:: https://readthedocs.org/projects/cfglib/badge/?version=latest
        :target: https://cfglib.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://codecov.io/gh/swarmer/cfglib-py/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/swarmer/cfglib-py


An extensible configuration library


* Free software: MIT license
* Documentation: https://cfglib.readthedocs.io.


Features
--------

* Describe config schema and perform validation
* Numerous utils to compose configs from multiple sources, etc.
* Read settings from environment
